/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package mycode;

/**
 *
 * @author Robin
 */
//Question 5
//Q5.1 - 1
//application class created
public class CandidatePaperUI {
    public static void main (String args[])
    {
        //Q5.2 - 1
        //create CandidatePaperManager object
        CandidatePaperManager cpm = new CandidatePaperManager();
        
        //Q5.3 - 1
        //calling the displayAllCandidates method
        System.out.println(cpm.displayAllCandidates());
        
        //Q5.4 - 2
        //calling the sortByYear method and redisplaying
        cpm.sortByYear();
        System.out.println(cpm.displayAllCandidates());
        //Q7.3 - 1
        //call the reviewResearchPapers method
        System.out.println(cpm.reviewResearchPapers());
        
        //Q8.2 - 2
        //call doctoralCandidates method in correct place
        System.out.println(cpm.doctoralCandidates());
        
      
      
        
        
        
      
    }
}
